@@ -264,7 +264,10 @@ class Manga:
                 current_etag = fp.read()
 
         # Save cover image file
-        cover_data, etag, _rtime = self.server.get_manga_cover_image(url, current_etag)
+        try:
+            cover_data, etag, _rtime = self.server.get_manga_cover_image(url, current_etag)
+        except Exception:
+            return
         if cover_data is None:
             return
 
@@ -454,7 +457,7 @@ class Manga:
 
                 rank = get_free_rank(rank)
                 if row:
-                    # Update changes
+                    # Update chapter
                     changes = {}
 
                     # Common fields
@@ -479,8 +482,15 @@ class Manga:
                     rank += 1
                 else:
                     # Add new chapter
+
+                    # Ensure chapter num and volume num are numbers
+                    for key in ('num', 'num_volume'):
+                        if chapter_data.get(key) is not None:
+                            num = str(chapter_data[key])
+                            chapter_data[key] = remove_number_leading_zero(num) if is_number(num) else None
+
+                    # Used today if not date is provided
                     if not chapter_data.get('date'):
-                        # Used today if not date is provided
                         chapter_data['date'] = datetime.date.today()
 
                     chapter_data.update(dict(
@@ -588,7 +598,7 @@ class Chapter:
     def number(self):
         """ Returns chapter number"""
         num = None
-        if self.num:
+        if self.num and is_number(self.num):
             num = self.num
 
         elif is_number(self.slug):
